package com.config.example;

import javax.annotation.PostConstruct;

import org.apache.cxf.endpoint.Client;
import org.apache.cxf.ext.logging.LoggingInInterceptor;
import org.apache.cxf.ext.logging.LoggingOutInterceptor;
import org.apache.cxf.frontend.ClientProxy;
import org.apache.cxf.jaxws.JaxWsProxyFactoryBean;
import org.apache.cxf.transport.http.HTTPConduit;
import org.apache.cxf.transports.http.configuration.ConnectionType;
import org.apache.cxf.transports.http.configuration.HTTPClientPolicy;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.env.Environment;

import com.example.wsdl.WeatherSoap;

@Configuration
public class ImportJavaServiceConfiguration {

    private Logger logger = LoggerFactory.getLogger(this.getClass());
    
    @Autowired
    private Environment env;
    
    @PostConstruct
    public void init() {
        logger.info("Import Java Config Done");
    }

    @Bean
    public WeatherSoap myWebService() {
        String url = env.getProperty("ws.endpoint.url");
        JaxWsProxyFactoryBean factoryBean = new JaxWsProxyFactoryBean();
        factoryBean.setAddress(url);
        
        factoryBean.getInInterceptors().add(new LoggingInInterceptor());
        factoryBean.getOutInterceptors().add(new LoggingOutInterceptor());
        factoryBean.getInFaultInterceptors().add(new LoggingInInterceptor());
        factoryBean.getOutFaultInterceptors().add(new LoggingOutInterceptor());
        
        WeatherSoap service = factoryBean.create(WeatherSoap.class);
        
        Client client = ClientProxy.getClient(service);
        HTTPConduit conduit = (HTTPConduit) client.getConduit();
        
        conduit.setClient(new HTTPClientPolicy());
        conduit.getClient().setReceiveTimeout(2000);
        conduit.getClient().setConnectionTimeout(2000);
        conduit.getClient().setConnection(ConnectionType.KEEP_ALIVE);
        conduit.getClient().setAutoRedirect(true);
        conduit.getClient().setAllowChunking(true);
        conduit.getClient().setMaxRetransmits(1);
        
        return service;
    }
}
